function f = HccpenL1adapBIC4(n,m,r,u,sig,G,M)

%%%Inputs:
%n size of each training sample.
%m size of the test sample.
%r a parameter of the model related to the correlations between the covariables.
%u proportion of outliers.
%sig a parameter of the model (not necessarily the variance of the noise).
%G  grid for the BIC criterion.
%M number of training samples.

%%%Outputs:
%f.salphabeta estimations of s, alpha and beta.
%f.RPE Relative Prediction Error.
%f.lambdaopt regularization parameters.

%intercept of the model
alpha0=1;

%coefficient of each covariable
beta0=[3,1.5,0,0,2,0,0,0]';
p=length(beta0);

%salphabeta starts at 0
salphabeta1=zeros(p+2,M);
%salphabeta2=zeros(p+2,M);
%salphabeta3=zeros(p+2,M);

 

%lambdaopt starts at 0
lambdaopt=zeros(1,M); 
%lambdaopt2=zeros(1,M); 
%lambdaopt3=zeros(1,M); 

% Reseting the generator of random numbers to its initial state 

rand('state',0); 

randn('state',0);

%generating the design matrix of each training sample

Xtr=moygeneration(n,r);

%generating the test sample

Xte=moygeneration(m,r);

for j=1:M,

%generating the labels of the training sample according to the model
Ytr=alpha0+Xtr*beta0+sig*mixtgaussrnd(u,n)';

%Calculation of the estimator on the training sample
H=HccpenL1adapXYBIC4(Xtr,Ytr,G);
salphabeta1(:,j)=H.salphabeta1;
%salphabeta2(:,j)=H.salphabeta2;
%salphabeta3(:,j)=H.salphabeta3;
%
lambdaopt1(j)=H.lambdaopt1;
%lambdaopt2(j)=H.lambdaopt2;
%lambdaopt3(j)=H.lambdaopt3;
%
%salbet=H.salbet;  %temporaire
%loss1=H.loss1;    %temporaire
%loss2=H.loss2;    %temporaire
%loss3=H.loss3;    %temporaire
%BIC1=H.BIC1;
%BIC2=H.BIC2;
%BIC3=H.BIC3;


end
%Calculation of the RPE on the test set
beta=salphabeta1(3:end,:);
alpha=salphabeta1(2,:);
betaerr=beta-repmat(beta0,1,M);
alphaerr=alpha-repmat(alpha0,1,M);
alphaerr1=repmat(alphaerr,m,1);
alphabetaerr=alphaerr1+Xte*betaerr;
RPE1=mean(alphabetaerr.^2,1)/(sig^2*(1+(225-1)*u));
%
%
%beta=salphabeta2(3:end,:);
%alpha=salphabeta2(2,:);
%betaerr=beta-repmat(beta0,1,M);
%alphaerr=alpha-repmat(alpha0,1,M);
%alphaerr1=repmat(alphaerr,m,1);
%alphabetaerr=alphaerr1+Xte*betaerr;
%RPE2=mean(alphabetaerr.^2,1)/(sig^2*(1+(225-1)*u));
%
%
%
%beta=salphabeta3(3:end,:);
%alpha=salphabeta3(2,:);
%betaerr=beta-repmat(beta0,1,M);
%alphaerr=alpha-repmat(alpha0,1,M);
%alphaerr1=repmat(alphaerr,m,1);
%alphabetaerr=alphaerr1+Xte*betaerr;
%RPE3=mean(alphabetaerr.^2,1)/(sig^2*(1+(225-1)*u));
%
%
%
%
%
%
%
%
f.salphabeta1=salphabeta1;
%f.salphabeta2=salphabeta2;
%f.salphabeta3=salphabeta3;
%
f.RPE1=RPE1;
%f.RPE2=RPE2;
%f.RPE3=RPE3;
f.lambdaopt1=lambdaopt1;
%f.lambdaopt2=lambdaopt2;
%f.lambdaopt3=lambdaopt3;
%f.salbet=salbet; %temporaire
%
%
%f.loss1=loss1;   %temporaire
%f.loss2=loss2;   %temporaire
%f.loss3=loss3;   %temporaire
%
%
%
%f.BIC1=BIC1;
%f.BIC2=BIC2;
%f.BIC3=BIC3;

save salphabeta250HccBIC4.dat -ASCII salphabeta1
save RPE250HccBIC4.dat -ASCII RPE1
save lambdaopt250HccBIC4.dat -ASCII lambdaopt1
