function f = HccpenL1adapBIC4BruitDoubleExp(n,m,r,sig,G,M)

%%%Inputs:
%n size of each training sample.
%m size of the test sample.
%r a parameter of the model related to the correlations between the covariables.
%sig a parameter of the model (not necessarily the variance of the noise).
%G cross-validation grid.
%M number of training samples.

%%%Outputs:
%f.salphabeta estimations of s, alpha and beta.
%f.RPE Relative Prediction Error.
%f.lambdaopt regularization parameters.

%intercept of the model
alpha0=1;

%coefficient of each covariable
beta0=[3,1.5,0,0,2,0,0,0]';
p=length(beta0);

%staualphabeta starts at 0
salphabeta=zeros(p+2,M);

%lambdaopt starts at 0
lambdaopt=zeros(1,M); 

% Reseting the generator of random numbers to its initial state 

rand('state',0); 

randn('state',0);

%generating the design matrix of each training sample

Xtr=moygeneration(n,r);

%generating the test sample

Xte=moygeneration(m,r);

for j=1:M,

%generating the labels of the training sample according to the model
Ytr=alpha0+Xtr*beta0+sig*doubleexprnd(n)';

%Calculation of the estimator on the training sample
H=HccpenL1adapXYBIC4(Xtr,Ytr,G);
salphabeta1(:,j)=H.salphabeta1;
lambdaopt1(j)=H.lambdaopt1;

end
%Calculation of the RPE on the test set
beta=salphabeta1(3:end,:);
alpha=salphabeta1(2,:);
betaerr=beta-repmat(beta0,1,M);
alphaerr=alpha-repmat(alpha0,1,M);
alphaerr1=repmat(alphaerr,m,1);
alphabetaerr=alphaerr1+Xte*betaerr;
RPE1=mean(alphabetaerr.^2,1)/(sig^2*2);

f.salphabeta1=salphabeta1;
f.RPE1=RPE1;
f.lambdaopt1=lambdaopt1;

save salphabeta450HccBIC4.dat -ASCII salphabeta1
save RPE450HccBIC4.dat -ASCII RPE1
save lambdaopt450HccBIC4.dat -ASCII lambdaopt1


