function f = HccpenL1adapXYBIC4(Xtr,Ytr,G)

%%%Inputs:
%Xtr design matrix of the training sample
%Ytr labels vector of the training sample
%G grid for the BIC criterion

%%%Outputs: 
%f.salphabeta estimations of s, alpha and beta.
%f.lambdaopt regularization parameter.

q=length(G);
[n,p]=size(Xtr);

% threshold of the Huber loss.
M=1.345;

%Calculating the unpenalized estimator on the whole training sample.

cvx_begin
variables alphaUNP betaUNP(p) s v(n);
minimize (n*s+quad_over_lin(Ytr-alphaUNP-Xtr*betaUNP-v,s)+2*M*norm(v,1))
subject to
s > 0;
cvx_end


%salbet starts at 0
salbet=zeros(p+2,q);

%minima starts at 0
minima=zeros(1,q);

for j=1:q,
lambda=G(j);
H=HccpenL1adapXYlambdaforBIC4(Xtr,Ytr,lambda,betaUNP);
salbet(:,j)=H.salphabeta;
minima(j)=H.minimum;
end

%%% Choice of the regularization parameter by BIC Criterion. 
%loss and pen start at 0
loss1=zeros(1,q);
%loss2=zeros(1,q);
%loss3=zeros(1,q);
pen=zeros(1,q);

for j=1:q,
loss1(:,j)=log((minima(j)-G(j)*norm(salbet(3:end,j)./betaUNP,1))/n);
%loss2(:,j)=log(sqrt(4*pi*salbet(1,j))*(cdf('Normal',M*sqrt(2*salbet(1,j)),0,1)-0.5)+exp(-M*M*salbet(1,j))/M)+(salbet(1,j)/n)*sum(huber((Ytr-salbet(2,j)-Xtr*salbet(3:p+2,j))/(salbet(1,j)),M));
%loss3(:,j)=salbet(1,j)+(salbet(1,j)/n)*sum(huber((Ytr-salbet(2,j)-Xtr*salbet(3:p+2,j))/(salbet(1,j)),M));
bool=abs(salbet(3:p+2,j)) > 10^(-5);
pen(:,j)=(log(n)/(2*n))*sum(bool);
BIC1=loss1+pen;
%BIC2=loss2+pen;
%BIC3=loss3+pen;
end
[a1,b1]=min(BIC1);
lambdaBIC1=G(b1);
%
%[a2,b2]=min(BIC2);
%lambdaBIC2=G(b2);
%
%[a3,b3]=min(BIC3);
%lambdaBIC3=G(b3);
%
f.salphabeta1=salbet(:,b1);
%f.salphabeta2=salbet(:,b2);
%f.salphabeta3=salbet(:,b3);
%
f.lambdaopt1=lambdaBIC1;
%f.lambdaopt2=lambdaBIC2;
%f.lambdaopt3=lambdaBIC3;
%
%f.salbet=salbet; %temporaire
%f.loss1=loss1; %temporaire
%f.loss2=loss2;
%f.loss3=loss3;
%f.BIC1=BIC1;
%f.BIC2=BIC2;
%f.BIC3=BIC3;

