function f = LADpenL1adapBICBruitDoubleExp(n,m,r,sig,G,M)
%%%Inputs:
%n size of each training sample.
%m size of the test sample.
%r a parameter of the model related to the correlations between the covariables.
%u proportion of outliers.
%sig a parameter of the model (not necessarily the variance of the noise).
%G cross-validation grid.
%M number of training samples.

%%%Outputs:
%f.alphabeta estimations of alpha and beta.
%f.RPE Relative Prediction Error.
%f.lambdaopt regularization parameters.


%intercept of the model
alpha0=1;

%coefficient of each covariable
beta0=[3,1.5,0,0,2,0,0,0]';
p=length(beta0);

%alphabeta starts at 0
alphabeta=zeros(p+1,M);

%lambdaopt starts at 0
lambdaopt=zeros(1,M); 

% Reseting the generator of random numbers to its initial state 

rand('state',0); 

randn('state',0);

%generating the design matrix of each training sample

Xtr=moygeneration(n,r);

%generating the test sample

Xte=moygeneration(m,r);

for j=1:M,

%generating the labels of the training sample according to the model
Ytr=alpha0+Xtr*beta0+sig*doubleexprnd(n)';

%Calculation of the estimator on the training sample
H=LADpenL1adapXYBIC(Xtr,Ytr,G);
alphabeta(:,j)=H.alphabeta;
lambdaopt(j)=H.lambdaopt;

end
%Calculation of the RPE on the test set
beta=alphabeta(2:end,:);
alpha=alphabeta(1,:);
betaerr=beta-repmat(beta0,1,M);
alphaerr=alpha-repmat(alpha0,1,M);
alphaerr1=repmat(alphaerr,m,1);
alphabetaerr=alphaerr1+Xte*betaerr;
RPE=mean(alphabetaerr.^2,1)/(sig^2*2);

f.alphabeta=alphabeta;
f.RPE=RPE;
f.lambdaopt=lambdaopt;

save alphabet450LADBIC.dat -ASCII alphabeta
save RPE450LADBIC.dat -ASCII RPE
save lambdaopt450LADBIC.dat -ASCII lambdaopt


