function f = LADpenL1adapXYBIC(Xtr,Ytr,G)

%%%Inputs:
%Xtr design matrix of the training sample
%Ytr labels vector of the training sample
%G   grid for the BIC Criterion

%%%Outputs: 
%f.alphabeta estimations of alpha and beta.
%f.lambdaopt regularization parameter.

q=length(G);
[n,p]=size(Xtr);

%Calculating the unpenalized estimator on the whole training sample.

cvx_begin
variables alphaaUNP betaUNP(p);
minimize (norm(Ytr-alphaaUNP-Xtr*betaUNP,1))
cvx_end


%%% Calculating the estimators for each parameter of the grid and store all the corresponding estimations

%albet starts at 0
albet=zeros(p+1,q);

for j=1:q,
lambda=G(j);
H=LADpenL1adapXYlambdaforBIC(Xtr,Ytr,lambda,betaUNP);
albet(:,j)=H.alphabeta;
end

%%% Choice of the regularization parameter by BIC Criterion. 
%loss and pen start at 0
loss=zeros(1,q);
pen=zeros(1,q);

for j=1:q,
loss(:,j)=log(norm(Ytr-albet(1,j)-Xtr*albet(2:p+1,j),1));
bool=abs(albet(2:p+1,j)) > 10^(-5);
pen(:,j)=(log(n)/(2*n))*sum(bool);
BIC=loss+pen;
end

[a,b]=min(BIC);
lambdaBIC=G(b);

f.alphabeta=albet(:,b);
f.lambdaopt=lambdaBIC;
